Learn R Programming

OralOpioids (version 2.0.5)

Brand: Get the Brand name from Health Canada by using the DIN or NDC

Description

Brand retrieves the Brand name for an Oral Opioid from the HealthCanada_Opioid_Table.

Usage

Brand(Drug_ID, Opioid_Table)

Value

Brand name

Arguments

Drug_ID

A numeric value for the DIN or NDC. Exclude all zeros in front.

Opioid_Table

Opioid dataset which can be loaded by using the load_HealthCanada_Opioid_Table() or load_FDA_Opioid_Table() function. The name you use to call the function should be input here.

Examples

Run this code

FDA_Opioid_Table <- load_Opioid_Table(no_download = TRUE, country="US")
HealthCanada_Opioid_Table <- load_Opioid_Table(no_download = TRUE, country="Canada")
Brand(786535, HealthCanada_Opioid_Table)
Brand("0093-0058", FDA_Opioid_Table)

Run the code above in your browser using DataLab